==> ws-v3.70.8-src.tar.gz: ws-v3.70-8/samples/Python/pywscalc/newwin000.py <==
#----------------------------------------------------
# Wide Studio Application Ruby Lang Source File      
#            created by Wide Studio source generator 
#----------------------------------------------------
import mpfc

#--- OBJECT instance variable ---
newwin000 = None
newform_000 = None
newvlab_001 = None
newvbtn = {}

#--- OBJECT src ---

def _create_win_newwin000():
	global newvbtn
	global newwin000
	newwin000 = mpfc.WSCmainWindow(None,"newwin000")
	newwin000.initialize()
	newwin000.setProperty("name","newwin000")
	newwin000.setProperty("x",63);
	newwin000.setProperty("y",113);
	newwin000.setProperty("width",210);
	newwin000.setProperty("height",220);
	newwin000.setProperty("shadowThickness",1);
	newwin000.setProperty("backColor","grey80")
	newwin000.setProperty("vis",1);
	newwin000.addProcedure("resize","resizeep",10)
	newwin000.addProcedure("exit","exitep",32)

	global newform_000
	newform_000 = mpfc.WSCform(newwin000,"newform_000")
	newform_000.initialize()
	newform_000.setProperty("name","newform_000")
	newform_000.setProperty("x",5);
	newform_000.setProperty("y",5);
	newform_000.setProperty("width",200);
	newform_000.setProperty("height",50);
	newform_000.setProperty("shadowThickness",1);
	newform_000.setProperty("vis",1);

	global newvlab_001
	newvlab_001 = mpfc.WSCvlabel(newform_000,"newvlab_001")
	newvlab_001.initialize()
	newvlab_001.setProperty("shadowType",1);
	newvlab_001.setProperty("shadowThickness",1);
	newvlab_001.setProperty("backColor","gray35")
	newvlab_001.setProperty("bottomShadowColor","black")
	newvlab_001.setProperty("labelString","0")
	newvlab_001.setProperty("alignmentH",1);
	newvlab_001.setProperty("marginLeft",10);
	newvlab_001.setProperty("maxLength",13);
	newvlab_001.setProperty("font",2);
	newvlab_001.setProperty("name","newvlab_001")
	newvlab_001.setProperty("vis",1);
	newvlab_001.setProperty("x",5);
	newvlab_001.setProperty("y",15);
	newvlab_001.setProperty("width",190);
	newvlab_001.setProperty("foreColor","green")

	newvbtn[0] = mpfc.WSCvbtn(newwin000,"newvbtn[0]")
	newvbtn[0].initialize()
	newvbtn[0].setProperty("bottomShadowColor","gray55")
	newvbtn[0].setProperty("labelString","EXIT")
	newvbtn[0].setProperty("name","newvbtn[0]")
	newvbtn[0].setProperty("vis",1);
	newvbtn[0].setProperty("x",5);
	newvbtn[0].setProperty("y",60);
	newvbtn[0].setProperty("width",50);
	newvbtn[0].addProcedure("exit","exitep",2)

	newvbtn[1] = mpfc.WSCvbtn(newwin000,"newvbtn[1]")
	newvbtn[1].initialize()
	newvbtn[1].setProperty("bottomShadowColor","gray55")
	newvbtn[1].setProperty("labelString","7")
	newvbtn[1].setProperty("name","newvbtn[1]")
	newvbtn[1].setProperty("vis",1);
	newvbtn[1].setProperty("x",5);
	newvbtn[1].setProperty("y",90);
	newvbtn[1].setProperty("width",50);
	newvbtn[1].addProcedure("numbtnep","numbtnep",2)

	newvbtn[2] = mpfc.WSCvbtn(newwin000,"newvbtn[2]")
	newvbtn[2].initialize()
	newvbtn[2].setProperty("bottomShadowColor","gray55")
	newvbtn[2].setProperty("labelString","4")
	newvbtn[2].setProperty("name","newvbtn[2]")
	newvbtn[2].setProperty("vis",1);
	newvbtn[2].setProperty("x",5);
	newvbtn[2].setProperty("y",120);
	newvbtn[2].setProperty("width",50);
	newvbtn[2].addProcedure("numbtnep","numbtnep",2)

	newvbtn[3] = mpfc.WSCvbtn(newwin000,"newvbtn[3]")
	newvbtn[3].initialize()
	newvbtn[3].setProperty("bottomShadowColor","gray55")
	newvbtn[3].setProperty("labelString","1")
	newvbtn[3].setProperty("name","newvbtn[3]")
	newvbtn[3].setProperty("vis",1);
	newvbtn[3].setProperty("x",5);
	newvbtn[3].setProperty("y",150);
	newvbtn[3].setProperty("width",50);
	newvbtn[3].addProcedure("numbtnep","numbtnep",2)

	newvbtn[4] = mpfc.WSCvbtn(newwin000,"newvbtn[4]")
	newvbtn[4].initialize()
	newvbtn[4].setProperty("bottomShadowColor","gray55")
	newvbtn[4].setProperty("labelString","0")
	newvbtn[4].setProperty("name","newvbtn[4]")
	newvbtn[4].setProperty("vis",1);
	newvbtn[4].setProperty("x",5);
	newvbtn[4].setProperty("y",180);
	newvbtn[4].setProperty("width",50);
	newvbtn[4].addProcedure("numbtnep","numbtnep",2)

	newvbtn[5] = mpfc.WSCvbtn(newwin000,"newvbtn[5]")
	newvbtn[5].initialize()
	newvbtn[5].setProperty("bottomShadowColor","gray55")
	newvbtn[5].setProperty("labelString","AC")
	newvbtn[5].setProperty("name","newvbtn[5]")
	newvbtn[5].setProperty("vis",1);
	newvbtn[5].setProperty("x",55);
	newvbtn[5].setProperty("y",60);
	newvbtn[5].setProperty("width",50);
	newvbtn[5].addProcedure("ac","acbtnep",2)

	newvbtn[6] = mpfc.WSCvbtn(newwin000,"newvbtn[6]")
	newvbtn[6].initialize()
	newvbtn[6].setProperty("bottomShadowColor","gray55")
	newvbtn[6].setProperty("labelString","8")
	newvbtn[6].setProperty("name","newvbtn[6]")
	newvbtn[6].setProperty("vis",1);
	newvbtn[6].setProperty("x",55);
	newvbtn[6].setProperty("y",90);
	newvbtn[6].setProperty("width",51);
	newvbtn[6].addProcedure("numbtnep","numbtnep",2)

	newvbtn[7] = mpfc.WSCvbtn(newwin000,"newvbtn[7]")
	newvbtn[7].initialize()
	newvbtn[7].setProperty("bottomShadowColor","gray55")
	newvbtn[7].setProperty("labelString","5")
	newvbtn[7].setProperty("name","newvbtn[7]")
	newvbtn[7].setProperty("vis",1);
	newvbtn[7].setProperty("x",55);
	newvbtn[7].setProperty("y",120);
	newvbtn[7].setProperty("width",50);
	newvbtn[7].addProcedure("numbtnep","numbtnep",2)

	newvbtn[8] = mpfc.WSCvbtn(newwin000,"newvbtn[8]")
	newvbtn[8].initialize()
	newvbtn[8].setProperty("bottomShadowColor","gray55")
	newvbtn[8].setProperty("labelString","2")
	newvbtn[8].setProperty("name","newvbtn[8]")
	newvbtn[8].setProperty("vis",1);
	newvbtn[8].setProperty("x",55);
	newvbtn[8].setProperty("y",150);
	newvbtn[8].setProperty("width",50);
	newvbtn[8].addProcedure("numbtnep","numbtnep",2)

	newvbtn[9] = mpfc.WSCvbtn(newwin000,"newvbtn[9]")
	newvbtn[9].initialize()
	newvbtn[9].setProperty("bottomShadowColor","gray55")
	newvbtn[9].setProperty("labelString",".")
	newvbtn[9].setProperty("name","newvbtn[9]")
	newvbtn[9].setProperty("vis",1);
	newvbtn[9].setProperty("x",55);
	newvbtn[9].setProperty("y",180);
	newvbtn[9].setProperty("width",50);
	newvbtn[9].addProcedure("dotbtnep","dotbtnep",2)

	newvbtn[10] = mpfc.WSCvbtn(newwin000,"newvbtn[10]")
	newvbtn[10].initialize()
	newvbtn[10].setProperty("bottomShadowColor","gray55")
	newvbtn[10].setProperty("labelString","C")
	newvbtn[10].setProperty("name","newvbtn[10]")
	newvbtn[10].setProperty("vis",1);
	newvbtn[10].setProperty("x",105);
	newvbtn[10].setProperty("y",60);
	newvbtn[10].setProperty("width",50);
	newvbtn[10].addProcedure("clear","cbtnep",2)

	newvbtn[11] = mpfc.WSCvbtn(newwin000,"newvbtn[11]")
	newvbtn[11].initialize()
	newvbtn[11].setProperty("bottomShadowColor","gray55")
	newvbtn[11].setProperty("labelString","9")
	newvbtn[11].setProperty("name","newvbtn[11]")
	newvbtn[11].setProperty("vis",1);
	newvbtn[11].setProperty("x",105);
	newvbtn[11].setProperty("y",90);
	newvbtn[11].setProperty("width",50);
	newvbtn[11].addProcedure("numbtnep","numbtnep",2)

	newvbtn[12] = mpfc.WSCvbtn(newwin000,"newvbtn[12]")
	newvbtn[12].initialize()
	newvbtn[12].setProperty("bottomShadowColor","gray55")
	newvbtn[12].setProperty("labelString","6")
	newvbtn[12].setProperty("name","newvbtn[12]")
	newvbtn[12].setProperty("vis",1);
	newvbtn[12].setProperty("x",105);
	newvbtn[12].setProperty("y",120);
	newvbtn[12].setProperty("width",50);
	newvbtn[12].addProcedure("numbtnep","numbtnep",2)

	newvbtn[13] = mpfc.WSCvbtn(newwin000,"newvbtn[13]")
	newvbtn[13].initialize()
	newvbtn[13].setProperty("bottomShadowColor","gray55")
	newvbtn[13].setProperty("labelString","3")
	newvbtn[13].setProperty("name","newvbtn[13]")
	newvbtn[13].setProperty("vis",1);
	newvbtn[13].setProperty("x",105);
	newvbtn[13].setProperty("y",150);
	newvbtn[13].setProperty("width",50);
	newvbtn[13].addProcedure("numbtnep","numbtnep",2)

	newvbtn[14] = mpfc.WSCvbtn(newwin000,"newvbtn[14]")
	newvbtn[14].initialize()
	newvbtn[14].setProperty("bottomShadowColor","gray55")
	newvbtn[14].setProperty("labelString","+/-")
	newvbtn[14].setProperty("name","newvbtn[14]")
	newvbtn[14].setProperty("vis",1);
	newvbtn[14].setProperty("x",105);
	newvbtn[14].setProperty("y",180);
	newvbtn[14].setProperty("width",50);
	newvbtn[14].addProcedure("plus-minus","pmbtnep",2)

	newvbtn[15] = mpfc.WSCvbtn(newwin000,"newvbtn[15]")
	newvbtn[15].initialize()
	newvbtn[15].setProperty("bottomShadowColor","gray55")
	newvbtn[15].setProperty("labelString","/")
	newvbtn[15].setProperty("name","newvbtn[15]")
	newvbtn[15].setProperty("vis",1);
	newvbtn[15].setProperty("x",155);
	newvbtn[15].setProperty("y",60);
	newvbtn[15].setProperty("width",50);
	newvbtn[15].addProcedure("calculate","opbtnep",2)

	newvbtn[16] = mpfc.WSCvbtn(newwin000,"newvbtn[16]")
	newvbtn[16].initialize()
	newvbtn[16].setProperty("bottomShadowColor","gray55")
	newvbtn[16].setProperty("labelString","*")
	newvbtn[16].setProperty("name","newvbtn[16]")
	newvbtn[16].setProperty("vis",1);
	newvbtn[16].setProperty("x",155);
	newvbtn[16].setProperty("y",90);
	newvbtn[16].setProperty("width",50);
	newvbtn[16].addProcedure("calculate","opbtnep",2)

	newvbtn[17] = mpfc.WSCvbtn(newwin000,"newvbtn[17]")
	newvbtn[17].initialize()
	newvbtn[17].setProperty("bottomShadowColor","gray55")
	newvbtn[17].setProperty("labelString","-")
	newvbtn[17].setProperty("name","newvbtn[17]")
	newvbtn[17].setProperty("vis",1);
	newvbtn[17].setProperty("x",155);
	newvbtn[17].setProperty("y",120);
	newvbtn[17].setProperty("width",50);
	newvbtn[17].addProcedure("calculate","opbtnep",2)

	newvbtn[18] = mpfc.WSCvbtn(newwin000,"newvbtn[18]")
	newvbtn[18].initialize()
	newvbtn[18].setProperty("bottomShadowColor","gray55")
	newvbtn[18].setProperty("labelString","+")
	newvbtn[18].setProperty("name","newvbtn[18]")
	newvbtn[18].setProperty("vis",1);
	newvbtn[18].setProperty("x",155);
	newvbtn[18].setProperty("y",150);
	newvbtn[18].setProperty("width",50);
	newvbtn[18].addProcedure("calculate","opbtnep",2)

	newvbtn[19] = mpfc.WSCvbtn(newwin000,"newvbtn[19]")
	newvbtn[19].initialize()
	newvbtn[19].setProperty("bottomShadowColor","gray55")
	newvbtn[19].setProperty("labelString","=")
	newvbtn[19].setProperty("name","newvbtn[19]")
	newvbtn[19].setProperty("vis",1);
	newvbtn[19].setProperty("x",155);
	newvbtn[19].setProperty("y",180);
	newvbtn[19].setProperty("width",50);
	newvbtn[19].addProcedure("return","opbtnep",2)

	newwin000.setVisible(1)


_create_win_newwin000()
#--- end of src ---

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/samples/Python/pywscalc/newwin000.py <==
#----------------------------------------------------
# Wide Studio Application Ruby Lang Source File      
#            created by Wide Studio source generator 
#----------------------------------------------------
import mwt

#--- OBJECT instance variable ---
newwin000 = None
newform_000 = None
newvlab_001 = None
newvbtn = {}

#--- OBJECT src ---

def _create_win_newwin000():
	global newvbtn
	global newwin000
	newwin000 = mwt.WSCmainWindow(None,"newwin000")
	newwin000.initialize()
	newwin000.setProperty("name","newwin000")
	newwin000.setProperty("x",63);
	newwin000.setProperty("y",113);
	newwin000.setProperty("width",210);
	newwin000.setProperty("height",220);
	newwin000.setProperty("shadowThickness",1);
	newwin000.setProperty("backColor","grey80")
	newwin000.setProperty("vis",1);
	newwin000.addProcedure("resize","resizeep",10)
	newwin000.addProcedure("exit","exitep",32)

	global newform_000
	newform_000 = mwt.WSCform(newwin000,"newform_000")
	newform_000.initialize()
	newform_000.setProperty("name","newform_000")
	newform_000.setProperty("x",5);
	newform_000.setProperty("y",5);
	newform_000.setProperty("width",200);
	newform_000.setProperty("height",50);
	newform_000.setProperty("shadowThickness",1);
	newform_000.setProperty("vis",1);

	global newvlab_001
	newvlab_001 = mwt.WSCvlabel(newform_000,"newvlab_001")
	newvlab_001.initialize()
	newvlab_001.setProperty("shadowType",1);
	newvlab_001.setProperty("shadowThickness",1);
	newvlab_001.setProperty("backColor","gray35")
	newvlab_001.setProperty("bottomShadowColor","black")
	newvlab_001.setProperty("labelString","0")
	newvlab_001.setProperty("alignmentH",1);
	newvlab_001.setProperty("marginLeft",10);
	newvlab_001.setProperty("maxLength",13);
	newvlab_001.setProperty("font",2);
	newvlab_001.setProperty("name","newvlab_001")
	newvlab_001.setProperty("vis",1);
	newvlab_001.setProperty("x",5);
	newvlab_001.setProperty("y",15);
	newvlab_001.setProperty("width",190);
	newvlab_001.setProperty("foreColor","green")

	newvbtn[0] = mwt.WSCvbtn(newwin000,"newvbtn[0]")
	newvbtn[0].initialize()
	newvbtn[0].setProperty("bottomShadowColor","gray55")
	newvbtn[0].setProperty("labelString","EXIT")
	newvbtn[0].setProperty("name","newvbtn[0]")
	newvbtn[0].setProperty("vis",1);
	newvbtn[0].setProperty("x",5);
	newvbtn[0].setProperty("y",60);
	newvbtn[0].setProperty("width",50);
	newvbtn[0].addProcedure("exit","exitep",2)

	newvbtn[1] = mwt.WSCvbtn(newwin000,"newvbtn[1]")
	newvbtn[1].initialize()
	newvbtn[1].setProperty("bottomShadowColor","gray55")
	newvbtn[1].setProperty("labelString","7")
	newvbtn[1].setProperty("name","newvbtn[1]")
	newvbtn[1].setProperty("vis",1);
	newvbtn[1].setProperty("x",5);
	newvbtn[1].setProperty("y",90);
	newvbtn[1].setProperty("width",50);
	newvbtn[1].addProcedure("numbtnep","numbtnep",2)

	newvbtn[2] = mwt.WSCvbtn(newwin000,"newvbtn[2]")
	newvbtn[2].initialize()
	newvbtn[2].setProperty("bottomShadowColor","gray55")
	newvbtn[2].setProperty("labelString","4")
	newvbtn[2].setProperty("name","newvbtn[2]")
	newvbtn[2].setProperty("vis",1);
	newvbtn[2].setProperty("x",5);
	newvbtn[2].setProperty("y",120);
	newvbtn[2].setProperty("width",50);
	newvbtn[2].addProcedure("numbtnep","numbtnep",2)

	newvbtn[3] = mwt.WSCvbtn(newwin000,"newvbtn[3]")
	newvbtn[3].initialize()
	newvbtn[3].setProperty("bottomShadowColor","gray55")
	newvbtn[3].setProperty("labelString","1")
	newvbtn[3].setProperty("name","newvbtn[3]")
	newvbtn[3].setProperty("vis",1);
	newvbtn[3].setProperty("x",5);
	newvbtn[3].setProperty("y",150);
	newvbtn[3].setProperty("width",50);
	newvbtn[3].addProcedure("numbtnep","numbtnep",2)

	newvbtn[4] = mwt.WSCvbtn(newwin000,"newvbtn[4]")
	newvbtn[4].initialize()
	newvbtn[4].setProperty("bottomShadowColor","gray55")
	newvbtn[4].setProperty("labelString","0")
	newvbtn[4].setProperty("name","newvbtn[4]")
	newvbtn[4].setProperty("vis",1);
	newvbtn[4].setProperty("x",5);
	newvbtn[4].setProperty("y",180);
	newvbtn[4].setProperty("width",50);
	newvbtn[4].addProcedure("numbtnep","numbtnep",2)

	newvbtn[5] = mwt.WSCvbtn(newwin000,"newvbtn[5]")
	newvbtn[5].initialize()
	newvbtn[5].setProperty("bottomShadowColor","gray55")
	newvbtn[5].setProperty("labelString","AC")
	newvbtn[5].setProperty("name","newvbtn[5]")
	newvbtn[5].setProperty("vis",1);
	newvbtn[5].setProperty("x",55);
	newvbtn[5].setProperty("y",60);
	newvbtn[5].setProperty("width",50);
	newvbtn[5].addProcedure("ac","acbtnep",2)

	newvbtn[6] = mwt.WSCvbtn(newwin000,"newvbtn[6]")
	newvbtn[6].initialize()
	newvbtn[6].setProperty("bottomShadowColor","gray55")
	newvbtn[6].setProperty("labelString","8")
	newvbtn[6].setProperty("name","newvbtn[6]")
	newvbtn[6].setProperty("vis",1);
	newvbtn[6].setProperty("x",55);
	newvbtn[6].setProperty("y",90);
	newvbtn[6].setProperty("width",51);
	newvbtn[6].addProcedure("numbtnep","numbtnep",2)

	newvbtn[7] = mwt.WSCvbtn(newwin000,"newvbtn[7]")
	newvbtn[7].initialize()
	newvbtn[7].setProperty("bottomShadowColor","gray55")
	newvbtn[7].setProperty("labelString","5")
	newvbtn[7].setProperty("name","newvbtn[7]")
	newvbtn[7].setProperty("vis",1);
	newvbtn[7].setProperty("x",55);
	newvbtn[7].setProperty("y",120);
	newvbtn[7].setProperty("width",50);
	newvbtn[7].addProcedure("numbtnep","numbtnep",2)

	newvbtn[8] = mwt.WSCvbtn(newwin000,"newvbtn[8]")
	newvbtn[8].initialize()
	newvbtn[8].setProperty("bottomShadowColor","gray55")
	newvbtn[8].setProperty("labelString","2")
	newvbtn[8].setProperty("name","newvbtn[8]")
	newvbtn[8].setProperty("vis",1);
	newvbtn[8].setProperty("x",55);
	newvbtn[8].setProperty("y",150);
	newvbtn[8].setProperty("width",50);
	newvbtn[8].addProcedure("numbtnep","numbtnep",2)

	newvbtn[9] = mwt.WSCvbtn(newwin000,"newvbtn[9]")
	newvbtn[9].initialize()
	newvbtn[9].setProperty("bottomShadowColor","gray55")
	newvbtn[9].setProperty("labelString",".")
	newvbtn[9].setProperty("name","newvbtn[9]")
	newvbtn[9].setProperty("vis",1);
	newvbtn[9].setProperty("x",55);
	newvbtn[9].setProperty("y",180);
	newvbtn[9].setProperty("width",50);
	newvbtn[9].addProcedure("dotbtnep","dotbtnep",2)

	newvbtn[10] = mwt.WSCvbtn(newwin000,"newvbtn[10]")
	newvbtn[10].initialize()
	newvbtn[10].setProperty("bottomShadowColor","gray55")
	newvbtn[10].setProperty("labelString","C")
	newvbtn[10].setProperty("name","newvbtn[10]")
	newvbtn[10].setProperty("vis",1);
	newvbtn[10].setProperty("x",105);
	newvbtn[10].setProperty("y",60);
	newvbtn[10].setProperty("width",50);
	newvbtn[10].addProcedure("clear","cbtnep",2)

	newvbtn[11] = mwt.WSCvbtn(newwin000,"newvbtn[11]")
	newvbtn[11].initialize()
	newvbtn[11].setProperty("bottomShadowColor","gray55")
	newvbtn[11].setProperty("labelString","9")
	newvbtn[11].setProperty("name","newvbtn[11]")
	newvbtn[11].setProperty("vis",1);
	newvbtn[11].setProperty("x",105);
	newvbtn[11].setProperty("y",90);
	newvbtn[11].setProperty("width",50);
	newvbtn[11].addProcedure("numbtnep","numbtnep",2)

	newvbtn[12] = mwt.WSCvbtn(newwin000,"newvbtn[12]")
	newvbtn[12].initialize()
	newvbtn[12].setProperty("bottomShadowColor","gray55")
	newvbtn[12].setProperty("labelString","6")
	newvbtn[12].setProperty("name","newvbtn[12]")
	newvbtn[12].setProperty("vis",1);
	newvbtn[12].setProperty("x",105);
	newvbtn[12].setProperty("y",120);
	newvbtn[12].setProperty("width",50);
	newvbtn[12].addProcedure("numbtnep","numbtnep",2)

	newvbtn[13] = mwt.WSCvbtn(newwin000,"newvbtn[13]")
	newvbtn[13].initialize()
	newvbtn[13].setProperty("bottomShadowColor","gray55")
	newvbtn[13].setProperty("labelString","3")
	newvbtn[13].setProperty("name","newvbtn[13]")
	newvbtn[13].setProperty("vis",1);
	newvbtn[13].setProperty("x",105);
	newvbtn[13].setProperty("y",150);
	newvbtn[13].setProperty("width",50);
	newvbtn[13].addProcedure("numbtnep","numbtnep",2)

	newvbtn[14] = mwt.WSCvbtn(newwin000,"newvbtn[14]")
	newvbtn[14].initialize()
	newvbtn[14].setProperty("bottomShadowColor","gray55")
	newvbtn[14].setProperty("labelString","+/-")
	newvbtn[14].setProperty("name","newvbtn[14]")
	newvbtn[14].setProperty("vis",1);
	newvbtn[14].setProperty("x",105);
	newvbtn[14].setProperty("y",180);
	newvbtn[14].setProperty("width",50);
	newvbtn[14].addProcedure("plus-minus","pmbtnep",2)

	newvbtn[15] = mwt.WSCvbtn(newwin000,"newvbtn[15]")
	newvbtn[15].initialize()
	newvbtn[15].setProperty("bottomShadowColor","gray55")
	newvbtn[15].setProperty("labelString","/")
	newvbtn[15].setProperty("name","newvbtn[15]")
	newvbtn[15].setProperty("vis",1);
	newvbtn[15].setProperty("x",155);
	newvbtn[15].setProperty("y",60);
	newvbtn[15].setProperty("width",50);
	newvbtn[15].addProcedure("calculate","opbtnep",2)

	newvbtn[16] = mwt.WSCvbtn(newwin000,"newvbtn[16]")
	newvbtn[16].initialize()
	newvbtn[16].setProperty("bottomShadowColor","gray55")
	newvbtn[16].setProperty("labelString","*")
	newvbtn[16].setProperty("name","newvbtn[16]")
	newvbtn[16].setProperty("vis",1);
	newvbtn[16].setProperty("x",155);
	newvbtn[16].setProperty("y",90);
	newvbtn[16].setProperty("width",50);
	newvbtn[16].addProcedure("calculate","opbtnep",2)

	newvbtn[17] = mwt.WSCvbtn(newwin000,"newvbtn[17]")
	newvbtn[17].initialize()
	newvbtn[17].setProperty("bottomShadowColor","gray55")
	newvbtn[17].setProperty("labelString","-")
	newvbtn[17].setProperty("name","newvbtn[17]")
	newvbtn[17].setProperty("vis",1);
	newvbtn[17].setProperty("x",155);
	newvbtn[17].setProperty("y",120);
	newvbtn[17].setProperty("width",50);
	newvbtn[17].addProcedure("calculate","opbtnep",2)

	newvbtn[18] = mwt.WSCvbtn(newwin000,"newvbtn[18]")
	newvbtn[18].initialize()
	newvbtn[18].setProperty("bottomShadowColor","gray55")
	newvbtn[18].setProperty("labelString","+")
	newvbtn[18].setProperty("name","newvbtn[18]")
	newvbtn[18].setProperty("vis",1);
	newvbtn[18].setProperty("x",155);
	newvbtn[18].setProperty("y",150);
	newvbtn[18].setProperty("width",50);
	newvbtn[18].addProcedure("calculate","opbtnep",2)

	newvbtn[19] = mwt.WSCvbtn(newwin000,"newvbtn[19]")
	newvbtn[19].initialize()
	newvbtn[19].setProperty("bottomShadowColor","gray55")
	newvbtn[19].setProperty("labelString","=")
	newvbtn[19].setProperty("name","newvbtn[19]")
	newvbtn[19].setProperty("vis",1);
	newvbtn[19].setProperty("x",155);
	newvbtn[19].setProperty("y",180);
	newvbtn[19].setProperty("width",50);
	newvbtn[19].addProcedure("return","opbtnep",2)

	newwin000.setVisible(1)


_create_win_newwin000()
#--- end of src ---
